%global _eclipsedir %{_prefix}/lib/eclipse

%global _build_id_links alldebug

%bcond_without bootstrap

# Change following to 0 to default to no remote support when building
# for the first time in a buildroot -- this is needed to build:
#  * eclipse-remote
# which all make circular dependencies on cdt
%if %{without bootstrap}
%global _enable_remote_support 1
%else
%global _enable_remote_support 0
%endif

Epoch: 2

%global eclipse_base            %{_datadir}/eclipse
%global cdt_snapshot            org.eclipse.cdt-CDT_9_11_1

%global _cdtstandalonedir       %{_prefix}/lib/cdt-stand-alone-debugger

# we don't want to either provide or require anything from the stand-alone debugger install dir
%global __provides_exclude_from ^%{_cdtstandalonedir}/.*$
%global __requires_exclude_from ^%{_cdtstandalonedir}/.*$

%ifarch s390x x86_64 aarch64 ppc64le
    %global eclipse_arch %{_arch}
%endif

# Desktop file information
%global app_name %{?app_name_prefix}%{!?app_name_prefix:Eclipse} C/C++ Debugger
%global app_exec %{?app_exec_prefix} cdtdebug

# Glassfish EE APIs that moved to jakarta namespace
%global _jakarta_activation jakarta.activation-api
%global _jakarta_annotations jakarta.annotation-api
%global _jakarta_el jakarta.el-api
%global _jakarta_servlet jakarta.servlet-api
%global _jakarta_jaxb jakarta.xml.bind-api
%global _jakarta_jsp_api javax.servlet.jsp-api
%global _jakarta_jsp org.glassfish.web.jakarta.servlet.jsp

Summary:        Eclipse C/C++ Development Tools (CDT) plugin
Name:           eclipse-cdt
Version:        9.11.1
Release:        %mkrel 1
Group:          Development/Java
License:        EPL-2.0 and CPL
URL:            https://www.eclipse.org/cdt

Source0: https://git.eclipse.org/c/cdt/org.eclipse.cdt.git/snapshot/%{cdt_snapshot}.tar.xz

Source3: eclipse-cdt.desktop

# man-page for /usr/bin/cdtdebug
Source4: cdtdebug.man

# Following fixes cdtdebug.sh script to get proper platform filesystem plugin
Patch1: eclipse-cdt-cdtdebug.patch

# Following fixes Standalone Debugger config.ini file to use bundle symbolic names
Patch2: eclipse-cdt-config-ini.patch

# Following fixes Standalone Debugger README file to refer to /usr/bin/cdtdebug
Patch3: eclipse-cdt-cdtdebug-readme.patch

# Upstream Eclipse no longer supports non-64bit arches
ExcludeArch: s390 %{arm} %{ix86}

BuildRequires: java-11-openjdk-devel
BuildRequires: make
BuildRequires: rsync
BuildRequires: gcc-c++
BuildRequires: tycho
BuildRequires: tycho-extras
BuildRequires: desktop-file-utils
BuildRequires: google-gson
BuildRequires: jaxb-api
BuildRequires: jaxb-impl
BuildRequires: eclipse-egit
BuildRequires: eclipse-license2
BuildRequires: eclipse-platform
BuildRequires: eclipse-pde
BuildRequires: exec-maven-plugin
BuildRequires: maven-antrun-plugin
BuildRequires: freemarker
%if %{_enable_remote_support}
BuildRequires: eclipse-remote >= 2.1.0
%endif

Requires:      gdb make gcc-c++
%if %{_enable_remote_support}
Requires:      autoconf automake libtool
Requires:      eclipse-remote >= 2.1.0
%endif

# Added in F31
Obsoletes:     %{name}-tests < 2:9.7.0-4
Obsoletes:     %{name}-parsers < 2:9.7.0-4
# Added in F32
Obsoletes:     %{name}-docker < 2:9.11.0-6

# Added in F32 - this package absorbed launchbar
Obsoletes: eclipse-launchbar < 1:2.5.0-2
Provides:  eclipse-launchbar = %{epoch}:%{version}-%{release}

Recommends:    eclipse-linuxtools-libhover
Recommends:    eclipse-cdt-llvm
Recommends:    eclipse-cdt-qt

%description
Eclipse features and plugins that are useful for C and C++ development.

%package native
Summary:        Eclipse C/C++ Development Tools (CDT) Natives
Requires:       eclipse-platform

%description native
Architecture specific parts of CDT.

%package llvm
Summary:        Eclipse C/C++ Development Tools (CDT) LLVM
Requires:       %{name} = %{epoch}:%{version}-%{release}
%if 0%{?fedora} || 0%{?rhel} > 7 || 0%{?mageia}
Requires:       clang
Requires:       lldb
%endif

%description llvm
Optional llvm parsers for the CDT.

%package terminal
Summary:        Eclipse Terminal Plug-in
# Added in F32 - this package absorbed tm-terminal
Obsoletes: eclipse-tm-terminal < 4.5.200-2
Provides:  eclipse-tm-terminal = %{epoch}:%{version}-%{release}
Obsoletes: eclipse-tm-terminal-connectors < 4.5.200-2
Provides:  eclipse-tm-terminal-connectors = %{epoch}:%{version}-%{release}
Obsoletes: eclipse-tm-terminal-rse < 4.5.200-2
Provides:  eclipse-tm-terminal-rse = %{epoch}:%{version}-%{release}

%description terminal
An integrated Eclipse View for the local command prompt (console) or
remote hosts (SSH, Telnet, Serial).

%if %{_enable_remote_support}

%if 0%{?fedora} || 0%{?mageia}
%package arduino
Summary:        Arduino C++ Tools
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description arduino
Extensions to support Arduino C++ projects in Eclipse.
%endif

%package qt
Summary:        QT C++ Tools
Requires:       %{name} = %{epoch}:%{version}-%{release}
%if 0%{?fedora} || 0%{?rhel} > 7 || 0%{?mageia}
#for new qt project to work out of the box
Requires:       qtbase5-devel
Requires:       pkgconfig(Qt5Qml)
Requires:       pkgconfig(Qt5Quick)
%endif

%description qt
Extensions to support Qt projects and objects in the indexer.

%endif

%package sdk
Summary:        Eclipse C/C++ Development Tools (CDT) SDK plugin
Requires:       %{name} = %{epoch}:%{version}-%{release}
# Added in F32 - this package absorbed tm-terminal
Obsoletes: eclipse-tm-terminal-sdk < 4.5.200-2
Provides:  eclipse-tm-terminal-sdk = %{epoch}:%{version}-%{release}

%description sdk
Source for Eclipse CDT for use within Eclipse.

%prep
%setup -q -n %{cdt_snapshot}

# get desktop info
mkdir desktop
cp %{SOURCE3} desktop

# handle man page
mkdir man
cp %{SOURCE4} man

%patch1 -p0
%patch2 -p1
%patch3 -p1

# Fix tycho target environment
TYCHO_ENV="<environment><os>linux</os><ws>gtk</ws><arch>%{eclipse_arch}</arch></environment>"
%pom_xpath_set "pom:configuration/pom:environments" "$TYCHO_ENV" . core/org.eclipse.cdt.core.linux debug/org.eclipse.cdt.debug.application.product

# Add secondary arch support if we are building there
%ifarch s390x aarch64
sed -i -e 's/linux.x86_64"/linux.%{eclipse_arch}"/g' pom.xml
pushd core
sed -i -e 's/linux.x86_64 /linux.%{eclipse_arch} /g' org.eclipse.cdt.core.native/plugin.properties
sed -i -e 's/\\(x86_64\\)/(%{eclipse_arch})/g' org.eclipse.cdt.core.native/plugin.properties
cp -r org.eclipse.cdt.core.linux.x86_64 org.eclipse.cdt.core.linux.%{eclipse_arch}
rm -fr org.eclipse.cdt.core.linux.x86_64
pushd org.eclipse.cdt.core.linux.%{eclipse_arch}
mv os/linux/x86_64 os/linux/%{eclipse_arch}
popd
sed -i -e 's/x86_64/%{eclipse_arch}/g' org.eclipse.cdt.core.linux/pom.xml org.eclipse.cdt.core.linux.%{eclipse_arch}/{pom.xml,META-INF/MANIFEST.MF}
popd
sed -i -e 's/"org.eclipse.cdt.core.linux.x86_64"/"org.eclipse.cdt.core.linux.%{eclipse_arch}"/g' \
       -e 's/arch="x86_64"/arch="%{eclipse_arch}"/' releng/org.eclipse.cdt.native-feature/feature.xml
sed -i -e "s|org.eclipse.cdt.core.linux.x86_64</module>|org.eclipse.cdt.core.linux.%{eclipse_arch}</module>|g" pom.xml

# Ensure serial can be built on current arch
sed -i -e 's|linux/x86_64/|linux/%{eclipse_arch}/|' \
  native/org.eclipse.cdt.native.serial/jni/Makefile
sed -i -e 's/x86_64/%{eclipse_arch}/' \
  native/org.eclipse.cdt.native.serial/pom.xml
%endif

# Ensure correct platform fragments appear in config.ini ...
sed -i -e 's/x86_64/%{eclipse_arch}/' \
  debug/org.eclipse.cdt.debug.application.product/debug.product
# ... then remove fragments on platforms they aren't shipped
%ifarch s390x aarch64 ppc64le
sed -i '/filesystem.linux.%{eclipse_arch}/d' \
  debug/org.eclipse.cdt.debug.application.product/debug.product
sed -i '/net.linux.%{eclipse_arch}/d' \
  debug/org.eclipse.cdt.debug.application.product/debug.product
%endif

# Force the arch-specific plug-ins to be dir-shaped so that binary stripping works and the native files
# aren't loaded into the user.home .eclipse configuration
echo "Eclipse-BundleShape: dir" >> core/org.eclipse.cdt.core.linux.%{eclipse_arch}/META-INF/MANIFEST.MF
echo "Eclipse-BundleShape: dir" >> native/org.eclipse.cdt.native.serial/META-INF/MANIFEST.MF
sed -i -e '/library/s/library\//library\/*.c,library\/*.h,library\/Makefile/' \
  core/org.eclipse.cdt.core.linux/build.properties

# Remove pre-built natives
rm -rf native/org.eclipse.cdt.native.serial/os/* \
       core/org.eclipse.cdt.core.linux.*/os/*
mkdir -p native/org.eclipse.cdt.native.serial/os/linux/%{eclipse_arch} \
         core/org.eclipse.cdt.core.linux.%{eclipse_arch}/os/linux/%{eclipse_arch}

# Don't use the target configuration
%pom_disable_module releng/org.eclipse.cdt.target
%pom_xpath_remove "pom:configuration/pom:target"

# Don't need to build the p2 repos
%pom_disable_module releng/org.eclipse.cdt.repo
%pom_disable_module releng/org.eclipse.cdt.testing.repo

# Disable the jgit provider and force default packaging
%pom_remove_plugin org.eclipse.tycho:tycho-packaging-plugin

# Unnecessary plugins for RPM builds
%pom_remove_plugin org.jacoco:jacoco-maven-plugin
%pom_remove_plugin :maven-enforcer-plugin

# Disable unneeded additional parsers
sed -i -e '/<module>upc\//d' pom.xml
sed -i -e '/<module>lrparser\//d' pom.xml
sed -i -e '/<module>xlc\//d' pom.xml

# Don't build and ship test bundles
%pom_disable_module launchbar/org.eclipse.launchbar.core.tests
%pom_disable_module launchbar/org.eclipse.launchbar.ui.tests
%pom_disable_module org.eclipse.tm.terminal.test terminal/plugins
%pom_disable_module build/org.eclipse.cdt.autotools.tests
%pom_disable_module build/org.eclipse.cdt.autotools.ui.tests
%pom_disable_module build/org.eclipse.cdt.cmake.ui.tests
%pom_disable_module build/org.eclipse.cdt.make.core.tests
%pom_disable_module build/org.eclipse.cdt.make.ui.tests
%pom_disable_module build/org.eclipse.cdt.managedbuilder.core.tests
%pom_disable_module build/org.eclipse.cdt.managedbuilder.ui.tests
%pom_disable_module build/org.eclipse.cdt.meson.ui.tests
%pom_disable_module codan/org.eclipse.cdt.codan.checkers.ui.tests
%pom_disable_module codan/org.eclipse.cdt.codan.core.tests
%pom_disable_module core/org.eclipse.cdt.core.tests
%pom_disable_module core/org.eclipse.cdt.ui.tests
%pom_disable_module dsf-gdb/org.eclipse.cdt.dsf.gdb.multicorevisualizer.ui.tests
%pom_disable_module dsf-gdb/org.eclipse.cdt.dsf.gdb.tests
%pom_disable_module dsf-gdb/org.eclipse.cdt.tests.dsf.gdb
%pom_disable_module jtag/org.eclipse.cdt.debug.gdbjtag.core.tests
%pom_disable_module lsp/org.eclipse.cdt.lsp.core.tests
%pom_disable_module qt/org.eclipse.cdt.qt.ui.tests
%pom_disable_module windows/org.eclipse.cdt.msw.build.tests
%pom_disable_module testsrunner/org.eclipse.cdt.testsrunner.tests
%pom_disable_module releng/org.eclipse.cdt.testing
%pom_disable_module releng/org.eclipse.cdt.testing-feature

# Don't build and ship docker support
%pom_disable_module launch/org.eclipse.cdt.docker.launcher
%pom_disable_module launch/org.eclipse.cdt.docker.launcher-feature

# Disable autotools, and remote features if we are building a boot-strap build
%if ! %{_enable_remote_support}
%pom_disable_module org.eclipse.tm.terminal.connector.remote.feature terminal/features
%pom_disable_module org.eclipse.tm.terminal.connector.remote terminal/plugins
%pom_disable_module launchbar/org.eclipse.launchbar.remote
%pom_disable_module launchbar/org.eclipse.launchbar.remote.core
%pom_disable_module launchbar/org.eclipse.launchbar.remote.ui
%pom_disable_module build/org.eclipse.cdt.autotools.core
%pom_disable_module build/org.eclipse.cdt.autotools.docs
%pom_disable_module build/org.eclipse.cdt.autotools.ui
%pom_disable_module build/org.eclipse.cdt.autotools-feature
%pom_disable_module build/org.eclipse.cdt.cmake.core
%pom_disable_module build/org.eclipse.cdt.cmake.ui
%pom_disable_module build/org.eclipse.cdt.cmake-feature
%pom_disable_module debug/org.eclipse.cdt.debug.application
%pom_disable_module debug/org.eclipse.cdt.debug.application.product
%pom_disable_module debug/org.eclipse.cdt.debug.standalone-feature
%pom_disable_module cross/org.eclipse.cdt.launch.remote
%pom_disable_module cross/org.eclipse.cdt.launch.remote-feature
%pom_disable_module remote/org.eclipse.cdt.remote.core
%pom_disable_module qt/org.eclipse.cdt.qt.core
%pom_disable_module qt/org.eclipse.cdt.qt.ui
%pom_disable_module qt/org.eclipse.cdt.qt-feature
%pom_disable_module toolchains/arduino/org.eclipse.cdt.arduino.core
%pom_disable_module toolchains/arduino/org.eclipse.cdt.arduino.ui
%pom_disable_module toolchains/arduino/org.eclipse.cdt.arduino-feature
%pom_disable_module releng/org.eclipse.cdt.sdk
%pom_disable_module releng/org.eclipse.cdt.sdk-feature
%else
# Always disable arduino support on rhel
%if ! 0%{?fedora}
%pom_disable_module toolchains/arduino/org.eclipse.cdt.arduino.core
%pom_disable_module toolchains/arduino/org.eclipse.cdt.arduino.ui
%pom_disable_module toolchains/arduino/org.eclipse.cdt.arduino-feature
%endif
%endif

# Disable all bundles not relavent to the platform we currently building
for b in `ls core/ | grep -P -e 'org.eclipse.cdt.core\.(?!linux\.%{eclipse_arch}$|tests$|linux$|native$)'` ; do
  module=$(grep ">core/$b<" pom.xml || :)
  if [ -n "$module" ] ; then
    %pom_disable_module "core/$b"
    %pom_xpath_remove "plugin[@id='$b']" releng/org.eclipse.cdt.native-feature/feature.xml
  fi
done

# Disable meson (missing dep tm4e)
%pom_disable_module build/org.eclipse.cdt.meson.core
%pom_disable_module build/org.eclipse.cdt.meson.docs
%pom_disable_module build/org.eclipse.cdt.meson.ui
%pom_disable_module build/org.eclipse.cdt.meson.ui.editor
%pom_disable_module build/org.eclipse.cdt.meson-feature

# Disable lsp4e (missing dep)
%pom_disable_module lsp/org.eclipse.cdt.lsp.core
%pom_disable_module lsp/org.eclipse.cdt.lsp.ui
%pom_disable_module lsp/org.eclipse.cdt.lsp-feature
%pom_disable_module debug/org.eclipse.cdt.debug.dap
%pom_disable_module debug/org.eclipse.cdt.debug.dap-feature
%pom_disable_module jtag/org.eclipse.cdt.debug.dap.gdbjtag
%pom_disable_module jtag/org.eclipse.cdt.debug.dap.gdbjtag-feature

# Disable examples
%pom_disable_module visualizer/org.eclipse.cdt.visualizer.examples
%pom_disable_module dsf/org.eclipse.cdt.examples.dsf
%pom_disable_module dsf/org.eclipse.cdt.examples.dsf.pda
%pom_disable_module dsf/org.eclipse.cdt.examples.dsf.pda.ui
%pom_disable_module dsf/org.eclipse.cdt.examples.dsf-feature
%pom_disable_module dsf-gdb/org.eclipse.cdt.examples.dsf.gdb

# Fix freemarker dep
sed -i -e 's/org.freemarker/org.freemarker.freemarker/' \
  qt/org.eclipse.cdt.qt.core/META-INF/MANIFEST.MF \
  tools.templates/org.eclipse.tools.templates.freemarker/META-INF/MANIFEST.MF \
  build/org.eclipse.cdt.cmake.core/META-INF/MANIFEST.MF \
  debug/org.eclipse.cdt.debug.application.product/debug.product

# Fix deps javax -> jakarta
sed -i -e 's/>javax.annotation</>%{_jakarta_annotations}</' -e 's/"javax.annotation"/"%{_jakarta_annotations}"/' \
       -e 's/"javax.activation"/"%{_jakarta_activation}"/' -e 's/"javax.el"/"%{_jakarta_el}"/' -e 's/"javax.servlet"/"%{_jakarta_servlet}"/' \
       -e 's/"javax.servlet.jsp"/"%{_jakarta_jsp_api}"/' -e 's/"org.apache.jasper.glassfish"/"%{_jakarta_jsp}"/' \
  doc/org.eclipse.cdt.doc.isv/pom.xml \
  debug/org.eclipse.cdt.debug.application.product/debug.product

# Fix jaxb dep javax -> jakarta
sed -i -e 's/com.sun.xml.bind/com.sun.xml.bind.jaxb-impl/' \
  tools.templates/org.eclipse.tools.templates.freemarker/META-INF/MANIFEST.MF \
  debug/org.eclipse.cdt.debug.application.product/debug.product
sed -i -e 's/javax.xml.bind/%{_jakarta_jaxb}/' \
  tools.templates/org.eclipse.tools.templates.freemarker/build.properties \
  debug/org.eclipse.cdt.debug.application.product/debug.product

# Relax the version constraint of the gson dep
sed -i -e '/com.google.gson/s/;\(bundle-\)\?version=".*"//' \
  jtag/org.eclipse.cdt.debug.dap.gdbjtag/META-INF/MANIFEST.MF build/org.eclipse.cdt.managedbuilder.core/META-INF/MANIFEST.MF

%mvn_package "::pom::" __noinstall
%mvn_package "::jar:sources{,-feature}:" sdk
%mvn_package :*.sdk sdk
%mvn_package :*.doc.isv sdk
%mvn_package ":org.eclipse.cdt.core{,.native,.linux,.linux.%{eclipse_arch}}" native
%mvn_package ":org.eclipse.cdt.native{,.serial}" native
%mvn_package ":*.testsrunner*"
%mvn_package :org.eclipse.tools.templates.*
%mvn_package :org.eclipse.cdt.arduino* arduino
%mvn_package :org.eclipse.tm.terminal* terminal
%mvn_package ":org.eclipse.cdt.{managedbuilder.llvm,llvm.dsf}*" llvm
%mvn_package :org.eclipse.cdt.qt* qt
%mvn_package :org.eclipse.cdt.cmake* qt
%mvn_package :org.eclipse.cdt*
%mvn_package :org.eclipse.launchbar*

%build
export JAVA_HOME=%{_jvmdir}/java-11

export CFLAGS="${CFLAGS:-%optflags}"
export LDFLAGS="${LDFLAGS:-%ldflags}"

# Avoid running out of heap on s390x
export MAVEN_OPTS="-Xmx1024m"

# Avoid running out of heap on s390x
export MAVEN_OPTS="-Xmx1024m"

# Qualifier generated from last modification time of source tarball
QUALIFIER=$(date -u -d"$(stat --format=%y %{SOURCE0})" +%Y%m%d%H%M)
%mvn_build -j -f -- -Dtycho.local.keepTarget -Dnative=linux.%{eclipse_arch} -DforceContextQualifier=$QUALIFIER \
  -Pbuild-standalone-debugger-rcp -Dproject.build.sourceEncoding=UTF-8

%install
%mvn_install

# Avoid unnecessary dep on java-headless 11 due to Java 11 specific fragment
sed -i 's/>11</>1.8</' %{buildroot}/%{_datadir}/maven-metadata/*.xml

%if %{_enable_remote_support}
# We don't build the standalone debugger in bootstrap mode

binInstallDir=%{buildroot}/%{_bindir}
install -d -m755 $binInstallDir

libInstallDir=%{buildroot}/%{_cdtstandalonedir}
install -d -m755 $libInstallDir

#standalone debugger - copy it into right location
rsync -vrpl debug/org.eclipse.cdt.debug.application.product/target/products/org.eclipse.cdt.debug.application.product/linux/gtk/%{eclipse_arch}/cdt-stand-alone-debugger \
    %{buildroot}%{_prefix}/lib

# Symlink cdtdebug binary
pushd %{buildroot}%{_bindir}
    ln -s %{_cdtstandalonedir}/cdtdebug
popd

# Use distro-specific working dir to avoid clashing with upstream
sed -i -e '/-data/i-configuration' -e '/-data/i@user.home\/fcdtdebugger' \
       -e 's/@noDefault/@user.home\/workspace-fcdtdebug/' %{buildroot}%{_cdtstandalonedir}/cdtdebug.ini

%endif

# Install icons for standalone debugger
install -D debug/org.eclipse.cdt.debug.application/icons/cc32.png \
    %{buildroot}/usr/share/icons/hicolor/32x32/apps/%{name}.png
install -D debug/org.eclipse.cdt.debug.application/icons/cc48.png \
    %{buildroot}/usr/share/icons/hicolor/48x48/apps/%{name}.png
install -D debug/org.eclipse.cdt.debug.application/icons/cc128.png \
    %{buildroot}/usr/share/icons/hicolor/128x128/apps/%{name}.png
install -D debug/org.eclipse.cdt.debug.application/icons/cc.png \
    %{buildroot}/usr/share/icons/hicolor/256x256/apps/%{name}.png
install -d %{buildroot}/usr/share/pixmaps
ln -s /usr/share/icons/hicolor/256x256/apps/%{name}.png \
    %{buildroot}/usr/share/pixmaps/%{name}.png

# Fix permissions on native libraries
find %{buildroot} -name *.so -exec chmod +x {} \;

# Install desktop file
sed -i -e 's|Exec=cdtdebug|Exec=%{app_exec}|g' desktop/eclipse-cdt.desktop
sed -i -e 's|Name=Eclipse.*|Name=%{app_name}|g' desktop/eclipse-cdt.desktop
sed -i -e "s|Icon=eclipse|Icon=%{name}|g" desktop/eclipse-cdt.desktop
install -D desktop/eclipse-cdt.desktop %{buildroot}/usr/share/applications/%{name}.desktop
desktop-file-validate %{buildroot}/usr/share/applications/%{name}.desktop

# Install man page
install -D -m 644 man/cdtdebug.man %{buildroot}/%{_mandir}/man1/cdtdebug.1

%files -f .mfiles
%if %{_enable_remote_support}
%{_bindir}/cdtdebug
%{_cdtstandalonedir}/*
%endif
%{_datadir}/applications/*
%{_datadir}/pixmaps/*
%{_datadir}/icons/*/*/apps/*
%{_mandir}/man1/cdtdebug.1*
%license releng/org.eclipse.cdt.sdk/epl-v20.html

%files native -f .mfiles-native
%license releng/org.eclipse.cdt.sdk/epl-v20.html

%files sdk -f .mfiles-sdk
%license releng/org.eclipse.cdt.sdk/epl-v20.html

%files llvm -f .mfiles-llvm
%license releng/org.eclipse.cdt.sdk/epl-v20.html

%files terminal -f .mfiles-terminal
%license releng/org.eclipse.cdt.sdk/epl-v20.html

%if %{_enable_remote_support}

%files qt -f .mfiles-qt
%license releng/org.eclipse.cdt.sdk/epl-v20.html

%if 0%{?fedora} || 0%{?mageia}
%files arduino -f .mfiles-arduino
%license releng/org.eclipse.cdt.sdk/epl-v20.html
%endif

%endif




%changelog
* Thu Dec 17 2020 tv <tv> 2:9.11.1-1.mga8
+ Revision: 1660370
- bootstrap w/o remote_support
- Update to latest upstream release
- Drop docker tooling support
- Force build against Java 11
- Obsoletes tm-terminal
- Drop support for parsers for compilers that are not shipped
- Don't build and ship test bundles
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Fri Jul 19 2019 daviddavid <daviddavid> 2:9.7.0-1.mga8
+ Revision: 1422800
- Update to 2019-03 release
- Restrict to same architectures as Eclipse itself

* Sun Mar 10 2019 pterjan <pterjan> 2:9.6.0-7.mga7
+ Revision: 1373776
- Disable bootstrap on armv7hl

* Sat Mar 09 2019 pterjan <pterjan> 2:9.6.0-6.mga7
+ Revision: 1373286
- Fix bootstrap

* Sat Mar 09 2019 pterjan <pterjan> 2:9.6.0-4.mga7
+ Revision: 1373192
- Bootstrap on armv7hl

* Thu Jan 10 2019 daviddavid <daviddavid> 2:9.6.0-3.mga7
+ Revision: 1354090
- Patch to avoid requesting GTK2 as SWT backend
- Fix unexpected workspace directory change
- Ensure the native subpackage brings in the Eclipse Platform package

* Mon Jan 07 2019 daviddavid <daviddavid> 2:9.6.0-2.mga7
+ Revision: 1351110
- Update to 2018-12 release
- Switch to EPL 2.0 license
- Update to tagged sources and add patch for QT test runners problem
- Fix some build issues
- Avoid unintentional dependency on Java 11
- Fix for no longer present x86 native bundles from platform
- non-bootstrap build

* Sun Dec 23 2018 neoclust <neoclust> 2:9.5.3-1.mga7
+ Revision: 1344587
- New version

* Mon Nov 26 2018 wally <wally> 1:9.1.0-3.mga7
+ Revision: 1335327
- rebuild with guava18

* Sun Sep 23 2018 umeabot <umeabot> 1:9.1.0-2.mga7
+ Revision: 1297560
- Mageia 7 Mass Rebuild

* Mon Nov 28 2016 daviddavid <daviddavid> 1:9.1.0-1.mga6
+ Revision: 1070572
- Update to Neon.1 release
- Fix bootstrapping modes
- Fix binary stripping and permissions on native libraries
- Fix build on ppc64le

* Sat Oct 08 2016 neoclust <neoclust> 1:9.0.0-4.mga6
+ Revision: 1059540
- Rebuild for arm

* Thu Sep 15 2016 daviddavid <daviddavid> 1:9.0.0-3.mga6
+ Revision: 1053201
- Break cycle from main CDT package to the SDK

* Sun Jul 17 2016 neoclust <neoclust> 1:9.0.0-2.mga6
+ Revision: 1042405
- Rebuild for armv5

* Sun Jul 03 2016 daviddavid <daviddavid> 1:9.0.0-1.mga6
+ Revision: 1038407
- Update to Neon release
- Add missing build-requires

* Mon Jun 20 2016 pterjan <pterjan> 1:9.0.0-0.9.gitdff6b3b.2.mga6
+ Revision: 1036865
- Increase heap size on arm

* Wed Jun 15 2016 daviddavid <daviddavid> 1:9.0.0-0.9.gitdff6b3b.1.mga6
+ Revision: 1021575
- Move location code to find launchbar.core and ui.views.log into cdtdebug script
- Move setting of jar files for gson, xerces, xalan, xml.resolver, xml.serializer,
  and lucene.analysis into config.ini patch
- Update section of spec file that modifies standalone debugger config.ini
- Find org.eclipse.launchbar.core and org.eclipse.ui.views.log plugins
- Set jar files for com.google.gson, org.apache.xerces, org.apache.xalan,
  org.apache.xml.resolver, org.apache.xml.serializer, org.apache.lucene.analysis
- Add Requires eclipse-launchbar which is now required by standalone debugger

* Sat May 21 2016 daviddavid <daviddavid> 1:9.0.0-0.6.gitdff6b3b.1.mga6
+ Revision: 1017403
- New snapshot with natives build hooked in the maven build
- Fix natives compile for profiles not included upstream
- Add a patch to fix LLVM documentation, ebz#459567
- Drop unneeded BR on RSE

* Wed May 04 2016 daviddavid <daviddavid> 1:9.0.0-0.3.git0b93e81.1.mga6
+ Revision: 1009398
- Update to latest snapshot (9.0.0) for Neon support
- Fix broken reference to license issue to fix the build
- Fix launching stand-alone debugger

* Sat Apr 30 2016 daviddavid <daviddavid> 1:8.8.1-1.mga6
+ Revision: 1008377
- Update to upstream 8.8.1 release
- Use global instead of define
- Move more bundles into SDK that should be there
- Remove forbidden SCL macros
- Minor other changes to make it easier to auto-SCLise
- Make standalone debugger work with all versions of lucene

* Sat Mar 19 2016 daviddavid <daviddavid> 1:8.8.0-11.mga6
+ Revision: 992908
- rebuild without bootstrap

* Wed Mar 02 2016 neoclust <neoclust> 1:8.8.0-10.mga6
+ Revision: 982352
- Second rebuild of the java stack
- First rebuild of the java stack
- sync package eclipse-cdt with fedora


* Wed Feb 16 2011 Jeff Johnston  <jjohnstn@redhat.com> 1:7.0.1-5
- Add additional patch so glibc and libstdc++ libhover plug-ins reference
  local location for their libhover data.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:7.0.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jan 05 2011 Jeff Johnston  <jjohnstn@redhat.com> 1:7.0.1-3
- Add patch for Eclipse bug 286162.

* Thu Oct 07 2010 Jeff Johnston  <jjohnstn@redhat.com> 1:7.0.1-2
- Rebase CDT to Helios SR1 (7.0.1) including gdb hardware support
- Rebase Autotools/Libhover to Linux tools R0.6.1

* Wed Jul 14 2010 Jeff Johnston  <jjohnstn@redhat.com> 1:7.0.0-1
- Rebase CDT to Helios (7.0.0)
- Rebase Autotools/Libhover to Linux tools R0.6.0

* Tue May 18 2010 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.2-5
- Rebase Autotools/Libhover to Linux tools R0.5.1.
- Remove addbuilder patch which is already part of R0_5_1.
- Remove libhover template patch which is already part of R0_5_1.

* Thu May 06 2010 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.2-4
- Add libtool as a requirement.

* Fri Mar 19 2010 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.2-3
- Fix autotools local patch to add macros directory to build.properties
  of org.eclipse.linuxtools.cdt.autotools.core.

* Fri Mar 19 2010 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.2-2
- Check in missing maketargets patch.

* Thu Mar 18 2010 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.2-1
- Rebase CDT to Galileo SR2 (6.0.2).
- Rebase Autotools to Linux tools R0.5.
- Rebase Libhover to Linux tools R0.5.

* Fri Jan 29 2010 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.1-8
- Fix urls for autotools and libhover sources.
- Add source references for autotools and libhover fetch scripts.

* Fri Dec 11 2009 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.1-7
- Rebase Autotools to Linux tools 0.4.0.1 release.
- Rebase Libhover to Linux tools 0.4.0 release.
- Remove libhover patch which is now part of rebase.

* Wed Oct 28 2009 Alexander Kurtakov <akurtako@redhat.com> 1:6.0.1-6
- Disable mylyn bridge build, part of eclipse-mylyn srpm now.

* Tue Oct 27 2009 Alexander Kurtakov <akurtako@redhat.com> 1:6.0.1-5
- Sync build_id with upstream 6.0.1.

* Fri Oct 16 2009 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.1-4
- Rebase Autotools to 1.0.5.
- Add patch to move macro hover docs locally into Autotools plugin.

* Thu Oct 15 2009 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.1-3
- Include installed link for lpg java bundle in new cdt-parsers subpackage.

* Wed Oct 14 2009 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.1-2
- Ship new parsers sub-package which includes xlc, upc, and lrparser plug-ins.
- Require lpg-java-compat for build.

* Fri Oct 09 2009 Jeff Johnston  <jjohnstn@redhat.com> 1:6.0.1-1
- Rebase CDT to 6.0.1.

* Mon Oct 05 2009 Andrew Overholt <overholt@redhat.com> 1:6.0.0-11
- Build on ppc64

* Wed Sep 23 2009 Jeff Johnston <jjohnstn@redhat.com> 1:6.0.0-10
- Resolves #290247
- Upgrade libhover to 0.3.0.
- Add libhover patch to fix libstdc++ member resolution and
  to place libhover docs locally within libhover plugin.

* Wed Aug 12 2009 Andrew Overholt <overholt@redhat.com> 1:6.0.0-9
- Use launcher jar to run metadata generator instead of eclipse binary.

* Wed Aug 12 2009 Andrew Overholt <overholt@redhat.com> 1:6.0.0-8
- Remove shipping of content.xml.

* Wed Jul 29 2009 Jeff Johnston <jjohnstn@redhat.com> 1:6.0.0-7
- Resolves #514629

* Mon Jul 27 2009 Jeff Johnston <jjohnstn@redhat.com> 1:6.0.0-6
- Remove gcj_support.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:6.0.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Jul 24 2009 Jeff Johnston <jjohnstn@redhat.com> 6.0.0-3
- Bump release number.
- Update Autotools to v200907241319 which has CDT 6.0 fixes.

* Wed Jun 17 2009 Jeff Johnston <jjohnstn@redhat.com> 6.0.0-1
- Rebase CDT to 6.0.0.
- Rebase Autotools to v200906171600 snapshot.
- Resolves #280504, #280505, #280506, #280509.

* Mon Jun 15 2009 Jeff Johnston <jjohnstn@redhat.com> 5.0.2-3
- Resolves #280117.

* Wed Apr 08 2009 Jeff Johnston <jjohnstn@redhat.com> 5.0.2-2
- Bump release.

* Tue Apr 07 2009 Jeff Johnston <jjohnstn@redhat.com> 5.0.2-1
- Rebase autotools to 1.0.3.
- Rebase CDT to v200903191301 (5.0.2).

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:5.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Jan 16 2009 Jeff Johnston <jjohnstn@redhat.com> 5.0.1-2
- Rebase libhover to 0.1.1 and autotools to 1.0.2.
- Remove patch for 472731 which is already part of rebased autotools sources.

* Fri Nov 28 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.1-1
- Rebase to CDT 5.0.1.
- Fix bug in autotools project type detection.
- Resolve #472731

* Mon Nov 17 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.0-12
- Fix typo in autotools and libhover sources tarballs.
- Remove redundant patches which are already in new tarballs.

* Thu Nov 06 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.0-11
- Fix managed configurations dialog problem.
- Update libhover and autotools source tarballs to 20081106 snapshot.

* Thu Oct 16 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.0-10
- Change runtests section to remove new libhover plugin rather than old
  com.redhat.* autotools plugin.

* Thu Oct 16 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.0-9
- Fix org.eclipse.linuxtools.libhover.glibc plugin to add toc.xml to
  binary file list.

* Thu Oct 16 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.0-8
- Fix org.eclipse.linuxtools.libhover.feature to include
  org.eclipse.linuxtools.libhover.library_docs plugin.
- Add work-around patch for managed configurations dialog problem.

* Wed Oct 15 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.0-7
- Change to use new linuxtools version of autotools-1.0.1.
- Add build of libhover plugins again from linuxtools.

* Tue Sep 09 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.0-6
- Fix for NPE during alteration of Autotools configuration settings.
- Resolves #461647

* Thu Sep 04 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.0-5
- Fix for autotools plugin referencing invalid build nature.
- Resolves #461201

* Wed Aug 20 2008 Andrew Overholt <overholt@redhat.com> 5.0.0-4
- Add building and running of tests
- Remove LexerTests until 5.0.1
- Fix fetch script to use new location of PDE Build

* Mon Aug 11 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.0-3
- Fix build id to be 200806171202.

* Fri Aug 08 2008 Jeff Johnston <jjohnstn@redhat.com> 5.0.0-2
- Add autotools 1.0.0 which supports CDT 5.0.
- Use java -cp to build cdt and autotools instead of eclipse -nosplash.
- Replace fetched source with CDT_5_0_0 tagged sources.

* Wed Aug 06 2008 Andrew Overholt <overholt@redhat.com> 5.0.0-1
- Remove master and testing features
- Move files to dropins/cdt{,-mylyn,-sdk}/eclipse
- Generate p2 metadata

* Fri Aug 01 2008 Andrew Overholt <overholt@redhat.com> 5.0.0-1
- 5.0
- Add Mylyn sub-package
- Disable CPPUnit for now
- Disable autotools until a new snapshot is made that will build with 5.0

* Thu Jul 17 2008 Tom "spot" Callaway <tcallawa@redhat.com> 4.0.3-2
- fix license tag

* Fri Apr 04 2008 Jeff Johnston <jjohnstn@redhat.com> 4.0.3-1
- Rebase to CDT 4.0.3
- Patch openpty code to not reference stropts.h which is no longer shipped
- Update eclipse-cdt-no-tests.patch

* Mon Jan 28 2008 Jeff Johnston <jjohnstn@redhat.com> 4.0.1-4
- Update autotools to 0.9.6
- Includes generic shell script support for makefile generation on
  different platforms

* Wed Dec 05 2007 Jeff Johnston <jjohnstn@redhat.com> 4.0.1-3
- Resolves #412651, #412661, #385991 
- Rebase autotools to 0.9.5.3
- Adds glibc C library completion support.
- Fix clean by removal option.
- Add support for changes to configure/autogen command names.
- Add gcj checks for %%post and %%postun steps.

* Wed Oct 24 2007 Jeff Johnston <jjohnstn@redhat.com> 4.0.1-2
- Rebase autotools to 0.9.5.1
- Add autotools property tab for C/C++ build.
- Resolves #330701

* Thu Oct 04 2007 Jeff Johnston <jjohnstn@redhat.com> 4.0.1-1
- Use official CDT 4.0.1 source tarball
- Update autotools to 0.9.5
- Resolves #315811

* Tue Sep 25 2007 Andrew Overholt <overholt@redhat.com> 4.0.1-0.2.v200709241202cvs
- Fix moving of arch-specific plugins that haven't been updated to new
  version.

* Mon Sep 24 2007 Andrew Overholt <overholt@redhat.com> 4.0.1-0.1.v200709241202cvs
- 4.0.1 RC.
- Update autotools for Binaries fix.

* Thu Sep 13 2007 Jeff Johnston <jjohnstn@redhat.com> 4.0.0-7
- Resolves #288711
- Ensure that all features are unpacked.

* Mon Sep 10 2007 Jeff Johnston <jjohnstn@redhat.com> 4.0.0-6
- Resolves #274551, #253331, #254246, #254248
- Rebase Autotools to 0.9.3 

* Thu Aug 23 2007 Jeff Johnston <jjohnstn@redhat.com> 4.0.0-5
- Add eclipse-cvs-client dependency

* Fri Aug 17 2007 Jeff Johnston <jjohnstn@redhat.com> 4.0.0-4
- Fix release number in Autotools feature to be 0.9.2.

* Thu Aug 16 2007 Jeff Johnston <jjohnstn@redhat.com> 4.0.0-3
- Resolves #251412
- Rebase autotools to 0.9.2
- Add minimum java runtime requirement
- Add direct Autotools wizards
- Add autogen.sh options

* Fri Aug 10 2007 Jeff Johnston <jjohnstn@redhat.com> 4.0.0-2
- Add Epoch 1 back.

* Wed Aug 08 2007 Jeff Johnston <jjohnstn@redhat.com> 4.0.0-1
- Rebase to CDT 4.0.0
- Rebase Autotools to 0.9.1

* Mon Apr 16 2007 Jeff Johnston <jjohnstn@redhat.com> 3.1.2-3
- Add missing gif to org.eclipse.cdt.make.ui.
- Resolves: #236558

* Tue Feb 27 2007 Jeff Johnston <jjohnstn@redhat.com> 3.1.2-2
- Resolves: #229891, #230253, #205310, #229893
- Rebase autotools to 0.0.8.1 source.

* Wed Feb 21 2007 Jeff Johnston <jjohnstn@redhat.com> 3.1.2-1
- Rebase CDT to 3.1.2.
- Rebase autotools to 0.0.8 source.
- Replace subconsole patch with new build console patch.

* Mon Jan 29 2007 Jeff Johnston <jjohnstn@redhat.com> 3.1.1-8
- Resolves: #214624, #224644
- Rebase autotools to 0.0.7 source.

* Wed Jan 17 2007 Jeff Johnston <jjohnstn@redhat.com> 3.1.1-7
- Resolves: #222350
- Rebase autotools to 0.0.6.1 source.
- Add comments.
- Put arch-specific jars in library dir.

* Mon Dec 11 2006 Jeff Johnston <jjohnstn@redhat.com> 3.1.1-6
- Rebase autotools to 0.0.6 source.

* Wed Nov 15 2006 Jeff Johnston <jjohnstn@redhat.com> 3.1.1-5
- Add cppunit support.

* Mon Nov 06 2006 Andrew Overholt <overholt@redhat.com> 3.1.1-4
- Use the new location of copy-platform.

* Thu Oct 19 2006 Ben Konrath <bkonrath@redhat.com> 3.1.1-3
- Remove work-around for gcc bug # 20198.
- Do not include notice.html and epl-v10.html because these files are already
  included in the SDK.
- Put JNI libraries in %%{_libdir}/eclipse.
- Only build the CDT SDK.
- Fix build issue on non-x86 systems.
- Resolves: #208622

* Mon Oct 16 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.1-2
- Replace build patches with sed commands
- Resolves: #208622

* Mon Oct 16 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.1-2
- Fix build so only single platform is built at a time
- Bugzilla 208622

* Thu Sep 28 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.1-1
- Rebase autotools to 0.0.5 source.
- Rebase CDT to 3.1.1 source.
- Bugzilla 206719, 206359, 206164

* Mon Sep 11 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.0-3
- Add hover help for defined symbols
- Fix bug with defined symbol calculation on file that compilation
  string cannot be fetched for

* Fri Sep 01 2006 Ben Konrath <bkonrath@redhat.com> 3.1.0-2
- Remove jpp in release.
- Require java-gcj-compat >= 1.0.64.

* Tue Aug 29 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.0-1jpp_13fc
- Rebase autotools to 0.0.4 source.
- Use ScannerInfoProvider extension instead of DynamicScannerInfoProvider.
- Add sub-console support to CDT.

* Mon Aug 21 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.0-1jpp_12fc
- Fix build special targets when project hasn't configured yet.
- Fix to fully reconfigure after configuration options change.
- Fix configuration problem whereby config.sub complains.
- Bugzilla 200000, 201270, 203440

* Tue Aug 08 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.0-1jpp_11fc
- Fix Build Special Targets bug when importing a CVS project and
  using ManagedMake Project Wizard.
- Bugzilla 201269

* Mon Jul 31 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.0-1jpp_10fc
- Fix bug with library hover help.

* Tue Jul 25 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.0-1jpp_9fc
- Remove redundant runtime packages from sdk.

* Tue Jul 25 2006 Ben Konrath <bkonrath@redhat.com> 3.1.0-1jpp_8fc
- Add epoch to sdk requires.

* Mon Jul 24 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.0-1jpp_8fc
- Update autotools sources.
- Rebuild.

* Mon Jul 24 2006 Ben Konrath <bkonrath@redhat.com> 3.1.0-1jpp_7fc
- Rebuld.

* Sat Jul 22 2006 Jakub Jelinek <jakub@redhat.com> 3.1.0-1jpp_6fc
- Rebuilt

* Thu Jul 20 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.0-1jpp_5fc
- Split into main package and sdk sub-package.

* Thu Jul 20 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.0-1jpp_4fc
- Add Autotools plug-ins via additional source tarball.

* Wed Jul 19 2006 Igor Foox  <ifoox@redhat.com> 3.1.0-1jpp_3fc
- Rebuild.

* Wed Jul 12 2006 Jeff Johnston  <jjohnstn@redhat.com> 3.1.0-1jpp_2fc
- Add dynamic scannerinfo extension used by Autotools plug-in.

* Mon Jul 10 2006 Andrew Overholt <overholt@redhat.com> 3.1.0-1jpp_1fc
- 3.1.0.

* Thu Jun 08 2006 Andrew Overholt <overholt@redhat.com> 3.1.0-0jpp_0fc.3.1.0RC2 
- 3.1.0 RC2.
- Remove unused hover patch.
- Use newly-created versionless pde.build symlink.
- Remove no-sdkbuild patch.

* Mon Apr 03 2006 Andrew Overholt <overholt@redhat.com> 3.0.2-1jpp_3fc
- Add ia64.

* Tue Mar 07 2006 Andrew Overholt <overholt@redhat.com> 3.0.2-1jpp_2fc
- Bump release.

* Mon Feb 13 2006 Andrew Overholt <overholt@redhat.com> 3.0.2-1jpp_1fc
- 3.0.2.

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1:3.0.1-1jpp_8fc
- bump again for double-long bug on ppc(64)

* Fri Feb 10 2006 Andrew Overholt <overholt@redhat.com> 3.0.1-1jpp_7fc
- Use Epoch in Requires (rh#180915).
- Require >= 3.1.2 but < 3.1.3 to ensure we get 3.1.2.

* Thu Feb 09 2006 Andrew Overholt <overholt@redhat.com> 3.0.1-1jpp_6fc
- Make it Require >= 3.1.2.

* Thu Feb 09 2006 Andrew Overholt <overholt@redhat.com> 3.0.1-1jpp_5fc
- Build against SDK 3.1.2.

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1:3.0.1-1jpp_5fc
- rebuilt for new gcc4.1 snapshot and glibc changes

* Tue Jan 10 2006 Andrew Overholt <overholt@redhat.com> 3.0.1-1jpp_4fc
- Rebuild against latest gcc.

* Fri Dec 30 2005 Andrew Overholt <overholt@redhat.com> 3.0.1-1jpp_3fc
- Fix %%files section to not be x86-specific.

* Fri Dec 16 2005 Andrew Overholt <overholt@redhat.com> 3.0.1-1jpp_2fc
- Build against gcc 4.1.

* Mon Nov 14 2005 Andrew Overholt <overholt@redhat.com> 3.0.1-1jpp_1fc
- 3.0.1.

* Fri Oct 21 2005 Andrew Overholt <overholt@redhat.com> 3.0.0_fc-2
- Rebuild against gcc 4.0.2

* Tue Aug 23 2005 Andrew Overholt <overholt@redhat.com> 3.0.0_fc-1
- Import new upstream version (3.0).

* Thu Jul 14 2005 Andrew Overholt <overholt@redhat.com> 3.0.0_fc-0.RC2.1
- Import new upstream version (3.0RC2).
- Use gbenson's new aot-compile-rpm and change requirements appropriately.
- Re-enable native compilation - let's see what happens.

* Wed Jun 22 2005 Andrew Overholt <overholt@redhat.com> 3.0.0_fc-0.M7.1
- Import new upstream version (3.0M7).
- Remove refactoring/build.properties patch (now unneeeded).

* Fri Jun 03 2005 Jeff Pound <jpound@redhat.com> 3.0.0_fc-0.M6.8
- Patch refactoring/build.properties to include plugin.properties.
- Temporarily move all *.so's to *.so.bak due to native compilation bug.
- Temporarily remove gcj .jar -> .so db population.

* Mon May 23 2005 Andrew Overholt <overholt@redhat.com> 3.0.0_fc-0.M6.7
- Bring in new I-build to enable jump to Eclipse 3.1M7 and fix some critical
  issues.

* Wed May 11 2005 Ben Konrath <bkonrath@redhat.com> 3.0.0_fc-0.M6.6
- Temporarily disable org.eclipse.cdt.managedbuilder.core_3.0.0/libmngbuildcore.jar.so.

* Wed Apr 27 2005 Phil Muldoon <pmuldoon@redhat.com> 3.0.0_fc-0.M6.5
- Changed to find-and-aot-compile build usage
- Added "if gcj_support" toggle
- Fixed installing all arch fragments (now only installs one (correct) arch)
- Redid BuildRequires and Requires to remove old/unneeded dependencies
- Cleaned %%eclipse_arch declares.

* Thu Apr 21 2005 Phil Muldoon <pmuldoon@redhat.com> 3.0.0_fc-0.M6.4
- Added Chris Moller's libhover patch

* Sat Apr 16 2005 Ben Konrath <bkonrath@redhat.com> 3.0.0_fc-0.M6.3
- Clean up spec file (remove references to old patches and rh docs).

* Fri Apr 15 2005 Phil Muldoon <pmuldoon@redhat.com> 3.0.0_fc-0.M6.2
- Generated tarball from official final tagged M6 build

* Mon Apr 11 2005 Phil Muldoon <pmuldoon@redhat.com> 3.0.0_fc-0.M6.1
- Fixed db path in java -cp
- Regenerated tarball from M6 canditate build
- Reworked patches for M6 canditate Build

* Thu Apr 07 2005 Phil Muldoon <pmuldoon@redhat.com> 3.0.0_fc-0.M5.4
- Changed Requires eclipse-ui to eclipse-platform
- Added Requires java-1.4.2-gcj-compat >= 1.4.2.0-40jpp_14rh
- Added Requires gcc-java >= 4.0.0-0.35

* Mon Apr 04 2005 Phil Muldoon <pmuldoon@redhat.com> 3.0.0_fc-0.M5.3
- Added eclipse-cdt-no-sdkbuild.patch to build for platform only (fc4 space crunch)

* Sun Apr 03 2005 Andrew Overholt <overholt@redhat.com> 3.0.0_fc-0.M5.2
- Make use of rebuild-gcj-db.
- Use system-wide classmap.db.

* Wed Mar 23 2005 Phil Muldoon <pmuldoon@redhat.com> 3.0.0-1
- Updated to upstream CDT 3.0.0 M5 sources
- Removed Source1 (rhdocs) for now
- Removed libhover patch until updated
- Added eclipse-cdt-platform-build-linux.patch
- Added eclipse-cdt-sdk-build-linux.patch
- Stopped tests build for now (Added eclipse-cdt-no-tests.patch)
- Added Requires gcc-java (bz# 151866)
- Added new central db logic

* Fri Mar 4 2005 Phil Muldoon <pmuldoon@redhat.com> 2.0.2-3
- Added x86_64 to ExclusiveArch

* Thu Mar 3 2005 Phil Muldoon <pmuldoon@redhat.com> 2.0.2-2
- Moved upstream sources back to 2.0.2
- Revered back to releng build
- Added native build sections to spec file

* Tue Jan 11 2005 Ben Konrath <bkonrath@redhat.com> 2.1.0-1
- add devel rpm and use the patched sources for it
- update sources to 2.1.0
- new build method that does not require pre-fetched sources

* Sun Nov 07 2004 Ben Konrath <bkonrath@redhat.com> 2.0.2-1
- Update sources to 2.0.2
- Change which files are unzipped in the install phase - this changed in 2.0.2
- Update Red Hat documentation sources
- Remove no-cvs-patch as it is no longer needed (no-cvs2-patch is still needed)
- Update ui-libhover-patch 
- Add how-to document for doc and source tarball generation
- Add fetch-tests-patch for tarball generation

* Mon Jul 26 2004 Jeremy Handcock <handcock@redhat.com> 2.0-11
- Update Red Hat documentation sources

* Fri Jul 23 2004 Tom Tromey <tromey@redhat.com> 2.0-10
- Set user.home on all java invocations

* Fri Jul 23 2004 Tom Tromey <tromey@redhat.com> 2.0-9
- Pass dontFetchAnything to the build

* Fri Jul 23 2004 Tom Tromey <tromey@redhat.com> 2.0-8
- Patch from Phil Muldoon to avoid cvs operations

* Fri Jul 23 2004 Jeremy Handcock <handcock@redhat.com> 2.0-7
- Don't build on ppc64
- Require eclipse-ui, not eclipse-platform

* Fri Jul 23 2004 Tom Tromey <tromey@redhat.com> 2.0-6
- Set user.home when building

* Wed Jul 21 2004 Tom Tromey <tromey@redhat.com> 2.0-5
- Make .so files executable

* Wed Jul 21 2004 Chris Moller <cmoller@redhat.com> 2.0-4
- Add texthover

* Tue Jul 20 2004 Jeremy Handcock <handcock@redhat.com> 2.0-4
- Update Red Hat documentation sources

* Fri Jul 16 2004 Tom Tromey <tromey@redhat.com> 2.0-3
- Make platform symlink tree before building

* Fri Jul 16 2004 Jeremy Handcock <handcock@redhat.com> 2.0-3
- Add Red Hat-specific documentation
- Use `name' macro in source and patch names
- Correct BuildRequires to eclipse-platform

* Tue Jul 13 2004 Jeremy Handcock <handcock@redhat.com> 2.0-2
- Don't require ant
- Prevent possible `build' section overload

* Mon Jul 12 2004 Tom Tromey <tromey@redhat.com> 2.0-2
- Document source fetching process
- Update to CDT 2.0 final
- Set -D_GNU_SOURCE when building

* Fri Jul  9 2004 Tom Tromey <tromey@redhat.com> 2.0-2
- Don't define prefix
- Don't require pango

* Fri Jul  9 2004 Jeremy Handcock <handcock@redhat.com> 2.0-2
- Update sources to include tests from upstream
- Add new build patch for CDT tests
- Build CDT tests, but don't install them

* Thu Jul  8 2004 Tom Tromey <tromey@redhat.com> 2.0-1
- Removed unused patch

* Thu Jul  8 2004 Jeremy Handcock <handcock@redhat.com> 2.0-1
- Revert previous patch; don't unset javacVerbose

* Thu Jul  8 2004 Jeremy Handcock <handcock@redhat.com> 2.0-1
- Unset javacVerbose

* Tue Jun 15 2004 Tom Tromey <tromey@redhat.com> 2.0-1
- Updated to 2.0 M8

* Mon Jan 19 2004 Tom Tromey <tromey@redhat.com> 1.2.1-1
- Initial version
